from Babaji import HeightPredictor

# Initialize the predictor (no need to pass URLs)
predictor = HeightPredictor()

# Predict height for a given weight
  # Example input
predicted_height = predictor.predict(78)
print(predicted_height)

